@@ -12,11 +12,8 @@
 #
 ##############################################################################
 import doctest
-import pkg_resources
-import unittest
 
 import zope.testbrowser.ftests.wsgitestapp
-import zope.testbrowser.wsgi
 import zope.testbrowser.tests.helper
 
 
@@ -24,18 +21,19 @@ def test_suite():
     flags = doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS
 
     suite = doctest.DocFileSuite(
-        'README.txt',
-        'cookies.txt',
         'fixed-bugs.txt',
         optionflags=flags,
         checker=zope.testbrowser.tests.helper.checker,
         package='zope.testbrowser')
 
     wire = doctest.DocFileSuite('over_the_wire.txt', optionflags=flags,
+                                checker=zope.testbrowser.tests.helper.checker,
                                 package='zope.testbrowser')
     wire.level = 2
+    suite.addTests(wire)
+
+    return suite
 
-    return unittest.TestSuite((suite, wire))
 
 # additional_tests is for setuptools "setup.py test" support
 additional_tests = test_suite
